aboutsummaryrefslogtreecommitdiffstats
path: root/src/tag/Tag.hxx
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2013-10-20 13:32:59 +0200
committerMax Kellermann <max@duempel.org>2013-10-20 13:32:59 +0200
commita78b2d84ed7c2a82c69c56125036e70b009a87b0 (patch)
treec8818c4111e9f2138cb66a38e1664ad5aa432bd4 /src/tag/Tag.hxx
parentcf4d80fc655a399615529bdd27e0be284754c5ab (diff)
downloadmpd-a78b2d84ed7c2a82c69c56125036e70b009a87b0.tar.gz
mpd-a78b2d84ed7c2a82c69c56125036e70b009a87b0.tar.xz
mpd-a78b2d84ed7c2a82c69c56125036e70b009a87b0.zip
TagType: rename enum tag_type to TagType
Diffstat (limited to 'src/tag/Tag.hxx')
-rw-r--r--src/tag/Tag.hxx20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/tag/Tag.hxx b/src/tag/Tag.hxx
index 4a1b16b39..4d8f1a4e8 100644
--- a/src/tag/Tag.hxx
+++ b/src/tag/Tag.hxx
@@ -110,7 +110,7 @@ struct Tag {
* @param value the value of the tag item (not null-terminated)
* @param len the length of #value
*/
- void AddItem(tag_type type, const char *value, size_t len);
+ void AddItem(TagType type, const char *value, size_t len);
/**
* Appends a new tag item.
@@ -119,11 +119,11 @@ struct Tag {
* @param type the type of the new tag item
* @param value the value of the tag item (null-terminated)
*/
- void AddItem(tag_type type, const char *value);
+ void AddItem(TagType type, const char *value);
/**
* Merges the data from two tags. If both tags share data for the
* same tag_type, only data from "add" is used.
*
* @return a newly allocated tag
*/
@@ -144,35 +144,35 @@ struct Tag {
* is present in this tag object.
*/
gcc_pure
- const char *GetValue(tag_type type) const;
+ const char *GetValue(TagType type) const;
/**
* Checks whether the tag contains one or more items with
* the specified type.
*/
gcc_pure
- bool HasType(tag_type type) const;
+ bool HasType(TagType type) const;
private:
- void AddItemInternal(tag_type type, const char *value, size_t len);
+ void AddItemInternal(TagType type, const char *value, size_t len);
};
/**
* Parse the string, and convert it into a #tag_type. Returns
* #TAG_NUM_OF_ITEM_TYPES if the string could not be recognized.
*/
gcc_pure
-enum tag_type
+TagType
tag_name_parse(const char *name);
/**
* Parse the string, and convert it into a #tag_type. Returns
* #TAG_NUM_OF_ITEM_TYPES if the string could not be recognized.
*
* Case does not matter.
*/
gcc_pure
-enum tag_type
+TagType
tag_name_parse_i(const char *name);
#endif
@@ -119,11 +119,11 @@ struct Tag {
/**
* Merges the data from two tags. If both tags share data for the
- * same tag_type, only data from "add" is used.
+ * same TagType, only data from "add" is used.
*
* @return a newly allocated tag
@@ -144,35 +144,35 @@ struct Tag {
};
/**
- * Parse the string, and convert it into a #tag_type. Returns
+ * Parse the string, and convert it into a #TagType. Returns
* #TAG_NUM_OF_ITEM_TYPES if the string could not be recognized.
*/
@@ -144,35 +144,35 @@ struct Tag {
tag_name_parse(const char *name);
/**
- * Parse the string, and convert it into a #tag_type. Returns
+ * Parse the string, and convert it into a #TagType. Returns
* #TAG_NUM_OF_ITEM_TYPES if the string could not be recognized.
*